@@ -265,8 +265,6 @@ static u_char*
 check_snmp_vsgroupmember(struct variable *vp, oid *name, size_t *length,
 			 int exact, size_t *var_len, WriteMethod **write_method)
 {
-	static uint32_t ip;
-	static struct in6_addr ip6;
 	oid *target, current[2], best[2];
 	int result;
 	size_t target_len;
@@ -351,7 +349,7 @@ check_snmp_vsgroupmember(struct variable *vp, oid *name, size_t *length,
 	case CHECK_SNMP_VSGROUPMEMBERTYPE:
 		if (be->is_fwmark)
 			long_ret.u = 1;
-		else if (be->range)
+		else if (inet_sockaddrcmp(&be->addr, &be->addr_end))
 			long_ret.u = 3;
 		else
 			long_ret.u = 2;
@@ -365,27 +363,23 @@ check_snmp_vsgroupmember(struct variable *vp, oid *name, size_t *length,
 		long_ret.u = (be->addr.ss_family == AF_INET6) ? 2:1;
 		return PTR_CAST(u_char, &long_ret);
 	case CHECK_SNMP_VSGROUPMEMBERADDRESS:
-		if (be->is_fwmark || be->range) break;
+		if (be->is_fwmark || inet_sockaddrcmp(&be->addr, &be->addr_end)) break;
 		RETURN_IP46ADDRESS(be);
 		break;
 	case CHECK_SNMP_VSGROUPMEMBERADDR1:
-		if (be->is_fwmark || !be->range) break;
+		if (be->is_fwmark || !inet_sockaddrcmp(&be->addr, &be->addr_end)) break;
 		RETURN_IP46ADDRESS(be);
 		break;
 	case CHECK_SNMP_VSGROUPMEMBERADDR2:
-		if (!be->range || be->is_fwmark) break;
+		if (!inet_sockaddrcmp(&be->addr, &be->addr_end) || be->is_fwmark) break;
 		if (be->addr.ss_family == AF_INET6) {
-			struct sockaddr_in6 *addr6 = PTR_CAST(struct sockaddr_in6, &be->addr);
+			struct sockaddr_in6 *addr6 = PTR_CAST(struct sockaddr_in6, &be->addr_end);
 			*var_len = 16;
-			memcpy(&ip6, &addr6->sin6_addr, sizeof(ip6));
-			ip6.s6_addr16[7] = htons(ntohs(ip6.s6_addr16[7]) + be->range);
-			return PTR_CAST(u_char, &ip6);
+			return PTR_CAST(u_char, &addr6->sin6_addr);
 		} else {
-			struct sockaddr_in *addr4 = PTR_CAST(struct sockaddr_in, &be->addr);
+			struct sockaddr_in *addr4 = PTR_CAST(struct sockaddr_in, &be->addr_end);
 			*var_len = 4;
-			ip = *PTR_CAST(uint32_t, &addr4->sin_addr);
-			ip += htonl(be->range);
-			return PTR_CAST(u_char, &ip);
+			return PTR_CAST(u_char, &addr4->sin_addr);
 		}
 		break;
 	case CHECK_SNMP_VSGROUPMEMBERPORT:
@@ -529,11 +523,9 @@ check_snmp_virtualserver(struct variable *vp, oid *name, size_t *length,
 	case CHECK_SNMP_VSHASUSPEND:
 		long_ret.u = v->ha_suspend?1:2;
 		return PTR_CAST(u_char, &long_ret);
-#ifdef IP_VS_SVC_F_ONEPACKET
 	case CHECK_SNMP_VSOPS:
 		long_ret.u = v->flags & IP_VS_SVC_F_ONEPACKET?1:2;
 		return PTR_CAST(u_char, &long_ret);
-#endif
 	case CHECK_SNMP_VSALPHA:
 		long_ret.u = v->alpha?1:2;
 		return PTR_CAST(u_char, &long_ret);
@@ -1438,7 +1430,7 @@ static struct variable8 check_vars[] = {
 	 check_snmp_virtualserver, 3, {3, 1, 67}},
 	{CHECK_SNMP_VSTUNNELTYPE, ASN_INTEGER, RONLY,
 	 check_snmp_virtualserver, 3, {3, 1, 68}},
-#ifdef _HAVE_IPSV_TUN_TYPE_
+#ifdef _HAVE_IPVS_TUN_TYPE_
 	{CHECK_SNMP_VSTUNNELPORT, ASN_UNSIGNED, RONLY,
 	 check_snmp_virtualserver, 3, {3, 1, 69}},
 #endif
@@ -1552,7 +1544,7 @@ static struct variable8 check_vars[] = {
 	 check_snmp_realserver, 3, {4, 1, 51}},
 	{CHECK_SNMP_RSTUNNELTYPE, ASN_INTEGER, RONLY,
 	 check_snmp_realserver, 3, {4, 1, 52}},
-#ifdef _HAVE_IPSV_TUN_TYPE_
+#ifdef _HAVE_IPVS_TUN_TYPE_
 	{CHECK_SNMP_RSTUNNELPORT, ASN_UNSIGNED, RONLY,
 	 check_snmp_realserver, 3, {4, 1, 53}},
 #endif
