@@ -33,9 +33,6 @@
 #include "layer4.h"
 #include "logger.h"
 #include "utils.h"
-#if !HAVE_DECL_SOCK_CLOEXEC
-#include "old_socket.h"
-#endif
 #ifdef _WITH_LVS_
 #include "check_api.h"
 #endif
@@ -491,15 +488,15 @@ body_cmd(thread_ref_t thread)
 {
 	smtp_t *smtp = THREAD_ARG(thread);
 	char *buffer;
-	char rfc822[80];
+	char rfc822[80];	/* Mon, 01 Mar 2021 09:44:08 +0000 */
 	time_t now;
-	struct tm *t;
+	struct tm t;
 
 	buffer = (char *)MALLOC(SMTP_BUFFER_MAX);
 
 	time(&now);
-	t = localtime(&now);
-	strftime(rfc822, sizeof(rfc822), "%a, %d %b %Y %H:%M:%S %z", t);
+	localtime_r(&now, &t);
+	strftime(rfc822, sizeof(rfc822), "%a, %d %b %Y %H:%M:%S %z", &t);
 
 	snprintf(buffer, SMTP_BUFFER_MAX, SMTP_HEADERS_CMD,
 		 rfc822, global_data->email_from, smtp->subject, smtp->email_to);
@@ -580,16 +577,6 @@ smtp_connect(smtp_t *smtp)
 		return;
 	}
 
-#if !HAVE_DECL_SOCK_NONBLOCK
-	if (set_sock_flags(smtp->fd, F_SETFL, O_NONBLOCK))
-		log_message(LOG_INFO, "Unable to set NONBLOCK on smtp_connect socket - %s (%d)", strerror(errno), errno);
-#endif
-
-#if !HAVE_DECL_SOCK_CLOEXEC
-	if (set_sock_flags(smtp->fd, F_SETFD, FD_CLOEXEC))
-		log_message(LOG_INFO, "Unable to set CLOEXEC on smtp_connect socket - %s (%d)", strerror(errno), errno);
-#endif
-
 	status = tcp_connect(smtp->fd, &global_data->smtp_server);
 
 	/* Handle connection status code */
