@@ -47,6 +47,16 @@
 /* Daemon dynamic data structure definition */
 #define KEEPALIVED_DEFAULT_DELAY	(60 * TIMER_HZ)
 
+#ifdef _WITH_NFTABLES_
+/* Used for arrays of protocol entries */
+typedef enum {
+	TCP_INDEX,
+	UDP_INDEX,
+	SCTP_INDEX,
+	PROTO_INDEX_MAX
+} proto_index_t;
+#endif
+
 /* SSL specific data */
 typedef struct _ssl_data {
 	int				enable;
@@ -119,7 +129,7 @@ typedef struct _virtual_server_group_entry {
 	union {
 		struct {
 			struct sockaddr_storage	addr;
-			uint32_t	range;
+			struct sockaddr_storage	addr_end;
 			unsigned	tcp_alive;
 			unsigned	udp_alive;
 			unsigned	sctp_alive;
@@ -144,6 +154,9 @@ typedef struct _virtual_server_group {
 	bool				have_ipv4;
 	bool				have_ipv6;
 	bool				fwmark_no_family;
+#ifdef _WITH_NFTABLES_
+	unsigned			auto_fwmark[PROTO_INDEX_MAX];
+#endif
 
 	/* Linked list member */
 	list_head_t			e_list;
@@ -164,9 +177,7 @@ typedef struct _virtual_server {
 	char				sched[IP_VS_SCHEDNAME_MAXLEN];
 	uint32_t			flags;
 	uint32_t			persistence_timeout;
-#ifdef _HAVE_PE_NAME_
 	char				pe_name[IP_VS_PENAME_MAXLEN + 1];
-#endif
 	unsigned			forwarding_method;
 #ifdef _HAVE_IPVS_TUN_TYPE_
 	int				tun_type;	/* tunnel type */
@@ -249,6 +260,23 @@ real_weight(int64_t effective_weight)
 	return effective_weight;
 }
 
+#ifdef _WITH_NFTABLES_
+static inline proto_index_t
+protocol_to_index(int proto)
+{
+	if (proto == IPPROTO_TCP)
+		return TCP_INDEX;
+	if (proto == IPPROTO_UDP)
+		return UDP_INDEX;
+	if (proto == IPPROTO_SCTP)
+		return SCTP_INDEX;
+
+	log_message(LOG_INFO, "Unknown protocol %d at %s:%d in %s", proto, __func__, __LINE__, __FILE__);
+
+	return UDP_INDEX;
+}
+#endif
+
 /* Global vars exported */
 extern check_data_t *check_data;
 extern check_data_t *old_check_data;
