@@ -117,7 +117,7 @@ typedef struct _vrrp_sgroup {
 	list_head_t		track_ifp;		/* tracked_if_t - Interface state we monitor */
 	list_head_t		track_script;		/* Script state we monitor */
 	list_head_t		track_file;		/* tracked_file_monitor_t - Files whose value we monitor */
-#ifdef _WITH_CN_PROC_
+#ifdef _WITH_TRACK_PROCESS_
 	list_head_t		track_process;		/* tracked_process_t - Processes we monitor */
 #endif
 #ifdef _WITH_BFD_
@@ -235,7 +235,7 @@ typedef struct _vrrp_t {
 	list_head_t		track_ifp;		/* tracked_if_t - Interface state we monitor */
 	list_head_t		track_script;		/* tracked_sc_t - Script state we monitor */
 	list_head_t		track_file;		/* tracked_file_monitor_t - Files whose value we monitor */
-#ifdef _WITH_CN_PROC_
+#ifdef _WITH_TRACK_PROCESS_
 	list_head_t		track_process;		/* tracked_process_t - Processes we monitor */
 #endif
 #ifdef _WITH_BFD_
@@ -249,9 +249,7 @@ typedef struct _vrrp_t {
 	bool			track_saddr;		/* Fault state if configured saddr is missing */
 	struct sockaddr_storage	pkt_saddr;		/* Src IP address received in VRRP IP header */
 	int			rx_ttl_hop_limit;	/* Received TTL/hop limit returned */
-#ifdef IPV6_RECVPKTINFO
 	bool			multicast_pkt;		/* Last IPv6 packet received was multicast */
-#endif
 	list_head_t		unicast_peer;		/* unicast_peer_t - peers to send unicast advert to */
 	int			ttl;			/* TTL to send packet with if unicasting */
 	bool			check_unicast_src;	/* It set, check the source address of a unicast advert */
@@ -294,10 +292,8 @@ typedef struct _vrrp_t {
 							 */
 	bool			promote_secondaries;	/* Set promote_secondaries option on interface */
 	bool			evip_other_family;	/* There are eVIPs of the different address family from the vrrp family */
-#ifdef _HAVE_FIB_ROUTING_
 	list_head_t		vroutes;		/* ip_route_t - list of virtual routes */
 	list_head_t		vrules;			/* ip_rule_t - list of virtual rules */
-#endif
 	unsigned		adver_int;		/* locally configured delay between advertisements*/
 	unsigned		master_adver_int;	/* In v3, when we become BACKUP, we use the MASTER's
 							 * adver_int. If we become MASTER again, we use the
