@@ -30,8 +30,13 @@
 #include <sys/stat.h>
 #endif
 
+#include "bitops.h"
+#include "utils.h"
+
 #define	MAX_LOG_MSG	255
 
+extern int log_facility;		/* Optional logging facilities */
+
 #ifdef ENABLE_LOG_TO_FILE
 extern const char *log_file_name;
 #endif
@@ -44,11 +49,16 @@ extern void open_log_file(const char *, const char *, const char *, const char *
 extern void flush_log_file(void);
 extern void update_log_file_perms(mode_t);
 #endif
-extern void vlog_message(int facility, const char* format, va_list args)
+extern void vlog_message(const int facility, const char* format, va_list args)
 	__attribute__ ((format (printf, 2, 0)));
 extern void log_message(int priority, const char* format, ...)
 	__attribute__ ((format (printf, 2, 3)));
 extern void conf_write(FILE *fp, const char *format, ...)
 	__attribute__ ((format (printf, 2, 3)));
 
+static inline void
+open_syslog(const char *ident)
+{
+	openlog(ident, LOG_PID | ((__test_bit(LOG_CONSOLE_BIT, &debug)) ? LOG_CONS : 0), log_facility);
+}
 #endif
